InterpolatingComponent — pysm v3.0.0

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.0.0 »
- pysm Documentation »
- InterpolatingComponent

# InterpolatingComponent

class `pysm.` `InterpolatingComponent`(path, input_units, nside, interpolation_kind='linear', has_polarization=True, map_dist=None, verbose=False)

  Bases: `pysm.Model`

  PySM component interpolating between precomputed maps

  Parameters
    pathstr

      Path should contain maps named as the frequency in GHz e.g. 20.fits or 20.5.fits or 00100.fits

    input_unitsstr

      Any unit available in PySM (see `pysm.convert_units` e.g. `Jysr`, `MJsr`, `uK_RJ`, `K_CMB`).

    nsideint

      HEALPix NSIDE of the output maps

    interpolation_kindstring

      Currently only linear is implemented

    has_polarizationbool

      whether or not to simulate also polarization maps

    map_distpysm.MapDistribution

      Required for partial sky or MPI, see the PySM docs

    verbosebool

      Control amount of output

  Methods Summary

  `get_emission`(self, freqs[, weights]) | This function evaluates the component model at a either a single frequency, an array of frequencies, or over a bandpass.
  `get_filenames`(self, path) |
  `read_map_by_frequency`(self, freq) |
  `read_map_file`(self, freq, filename) |

  Methods Documentation

  `get_emission`(self, freqs:Unit("GHz"), weights=None) -> Unit("uK_RJ")

    This function evaluates the component model at a either a single frequency, an array of frequencies, or over a bandpass.

    Parameters
      freqs: float

        Frequency at which the model should be evaluated, assumed to be given in GHz.

    Returns
      ndarray

        Set of maps at the given frequency or frequencies. This will have shape (nfreq, 3, npix).

  `get_filenames`(self, path)
  `read_map_by_frequency`(self, freq)
  `read_map_file`(self, freq, filename)